@@ -1,3 +1,3 @@
+from .MarieGUI import MarieGUI
 from .Marie import Marie
-from .MarieReader import MarieReader
-from .MarieGUI import MarieGUI, app
+from .MarieReader import MarieReader
\ No newline at end of file
